From 02db0d55997580a9b4fd46a52e7da4802e76ecee Mon Sep 17 00:00:00 2001
From: Kyotaro Horiguchi <horikyota.ntt@gmail.com>
Date: Mon, 7 Apr 2025 15:03:46 +0900
Subject: [PATCH 2/2] Use "map.dat file" instead of "map file" in error
 messages

While pg_restore refers to "map.dat file" and "global.dat file"
explicitly, pg_dump uses the more generic term "map file". Update the
wording to consistently refer to the file as "map.dat file" in error
messages.
---
 src/bin/pg_dump/pg_dumpall.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/src/bin/pg_dump/pg_dumpall.c b/src/bin/pg_dump/pg_dumpall.c
index c112d5d22b8..71978d556aa 100644
--- a/src/bin/pg_dump/pg_dumpall.c
+++ b/src/bin/pg_dump/pg_dumpall.c
@@ -1660,10 +1660,10 @@ dumpDatabases(PGconn *conn, ArchiveFormat archDumpFormat)
 
 		snprintf(map_file_path, MAXPGPATH, "%s/map.dat", filename);
 
 		/* Create a map file (to store dboid and dbname) */
 		map_file = fopen(map_file_path, PG_BINARY_W);
 		if (!map_file)
-			pg_fatal("could not open map file: \"%s\"", strerror(errno));
+			pg_fatal("could not open map.dat file: \"%s\"", strerror(errno));
 	}
 
 	for (i = 0; i < PQntuples(res); i++)
@@ -1697,7 +1697,7 @@ dumpDatabases(PGconn *conn, ArchiveFormat archDumpFormat)
 			else
 				snprintf(dbfilepath, MAXPGPATH, "\"%s\"/\"%s\"", db_subdir, oid);
 
 			/* Put one line entry for dboid and dbname in map file. */
 			fprintf(map_file, "%s %s\n", oid, dbname);
 		}
 
@@ -1748,7 +1748,7 @@ dumpDatabases(PGconn *conn, ArchiveFormat archDumpFormat)
 		}
 	}
 
 	/* Close map file */
 	if (archDumpFormat != archNull)
 		fclose(map_file);
 
@@ -1660,10 +1660,10 @@ dumpDatabases(PGconn *conn, ArchiveFormat archDumpFormat)
 		snprintf(map_file_path, MAXPGPATH, "%s/map.dat", filename);
 
-		/* Create a map file (to store dboid and dbname) */
+		/* Create a map.dat file (to store dboid and dbname) */
 		map_file = fopen(map_file_path, PG_BINARY_W);
 		if (!map_file)
@@ -1697,7 +1697,7 @@ dumpDatabases(PGconn *conn, ArchiveFormat archDumpFormat)
 				snprintf(dbfilepath, MAXPGPATH, "\"%s\"/\"%s\"", db_subdir, oid);
 
-			/* Put one line entry for dboid and dbname in map file. */
+			/* Put one line entry for dboid and dbname in map.dat file. */
 			fprintf(map_file, "%s %s\n", oid, dbname);
 		}
@@ -1748,7 +1748,7 @@ dumpDatabases(PGconn *conn, ArchiveFormat archDumpFormat)
 	}
 
-	/* Close map file */
+	/* Close map.dat file */
 	if (archDumpFormat != archNull)
 		fclose(map_file);
-- 
2.43.5

